pub enum Strategy {
Simple,
Wide,
Deep,
Directory,
File,
}Expand description
Enum for describing how to generate a file structure This is used for generating random data for testing
Variants
Simple
Generate exactly the file structure requested
Wide
Generate a wide version of the file structure requested – half as deep, twice as wide
Deep
Generate a deep version of the file structure requested – twice as deep, half as wide
Directory
Generate a very shallow version of the file structure requested –
File
Generate one big file with the requested size at the specified path